==> mkdocs-material_9.5.50.orig.tar.gz: mkdocs-material-9.5.50/docs/insiders/index.md <==
# Insiders

Material for MkDocs Insiders offers an enhanced experience with early access to
exclusive features that aren't available in the community edition. Become a
sponsor and make use of these features directly!

You’ve already seen the benefits of using Material for MkDocs;
imagine what more you can achieve with Insiders. Your sponsorship helps us
continue to innovate and improve, ensuring Material for MkDocs remains a
cutting-edge tool. Discover how your contributions make a difference.

[&nbsp; Choose a sponsoring tier <span class="mdx-sponsorship-count" data-mdx-component="sponsorship-count"></span>][sponsoring-tiers]{ .md-button .md-button--primary .mdx-sponsorship-button }

  [sponsoring-tiers]: sponsoring-tiers.md

## Additional information

Explore the following section to learn more about Material for MkDocs, why
you should sponsor us, what's in it for you, and who is sponsoring us.

<div class="grid cards" markdown>

-   :fontawesome-solid-circle-question: &nbsp;
    __Why sponsor us__

    ---

    Learn how to support our goal of becoming the leading tool in documentation

    ---

    [:octicons-arrow-right-24: More information][Why sponsor us]

-   :material-gift: &nbsp;
    __What's in it for you__

    ---

    Discover exclusive benefits and features available only to our monthly sponsors

    ---

    [:octicons-arrow-right-24: More infomation][What's in it for you]

-   :fontawesome-solid-people-group: &nbsp;
    __Who is sponsoring__

    ---

    Get to know our awesome sponsors, financially backing Material for MkDocs

    ---

    [:octicons-arrow-right-24: More infomation][Who is sponsoring]

</div>

### Sponsoring guide

Learn how to become a sponsor of Material for MkDocs Insiders and start your
sponsorship journey by choosing the right tier for you:

<div class="grid cards" markdown>


-   :material-animation-outline: &nbsp;
    __Sponsoring tiers__

    ---

    Find the perfect monthly sponsoring tier that fits your needs and
    requirements

    ---

    [:octicons-arrow-right-24: More information][Sponsoring tiers]

-   :octicons-heart-fill-24:{ .mdx-heart } &nbsp;
    __How to sponsor__

    ---

    Follow our step-by-step guide on how to become a sponsor to get you started

    ---

    [:octicons-arrow-right-24: More information][How to sponsor]

</div>

### Additional information

If you require additional and detailed information about payment, billing,
access management, and more, here is everything you need to know:

<div class="grid cards" markdown>

-   :material-hand-coin: &nbsp;
    __Payment and billing__

    ---

    All the information you need about payment methods and billing cycles

    ---

    [:octicons-arrow-right-24: More infomation][Payment and billing]

-   :material-key-variant: &nbsp;
    __Access management__

    ---

    Learn about access management to Insiders – for individuals and
    organizations

    ---

    [:octicons-arrow-right-24: More infomation][Access management]

-   :material-clock-time-three: &nbsp;
    __Runtime and cancellation__

    ---

    Receive information on the duration of your sponsorship and the cancellation
    process

    ---

    [:octicons-arrow-right-24: More information][Runtime and cancellation]

-   :material-lock-open: &nbsp;
    __Privacy__

    ---

    Our commitment to your privacy – learn assurances on valuing your privacy

    ---

    [:octicons-arrow-right-24: More infomation][Privacy]

-   :material-briefcase: &nbsp;
    __License__

    ---

    Get details on the licensing of Material for MkDocs Insiders and its requirements

    ---

    [:octicons-arrow-right-24: More infomation][License]

-   :material-email: &nbsp;
    __Support__

    ---

    Overview of our support options available, ensuring you get the information
    you need

    ---

    [:octicons-arrow-right-24: More information][Support]

</div>

### Using Insiders

Once you have become a sponsor, you can start using Material for MkDocs Insiders,
get all the information you need to get started:

<div class="grid cards" markdown>

-   :material-download: &nbsp;
    __Getting started__

    ---

    Step-by-step instructions on how to install Material for MkDocs Insiders

    ---

    [:octicons-arrow-right-24: More information][Getting started]

-   :octicons-versions-16: &nbsp;
    __Changelog__

    ---

    Review the latest changes and additions to Material for MkDocs Insiders

    ---

    [:octicons-arrow-right-24: More infomation][Changelog]

-   :material-update:&nbsp;
    __Upgrade__

    ---

    Stay updated with the latest changes and improvements in the Insiders
    edition

    ---

    [:octicons-arrow-right-24: More infomation][Upgrade]

</div>

  [Why sponsor us]: why-sponsor-us.md
  [What's in it for you]: benefits.md
  [Who is sponsoring]: our-sponsors.md
  [Sponsoring tiers]: sponsoring-tiers.md
  [How to sponsor]: how-to-sponsor.md
  [Payment and billing]: payment-and-billing.md
  [Access management]: access-management.md
  [Runtime and cancellation]: runtime-and-cancellation.md
  [Privacy]: privacy.md
  [License]: license.md
  [Support]: ../support.md
  [Getting started]: getting-started.md
  [Changelog]: ../changelog/index.md
  [Upgrade]: upgrade.md

----

__We're looking forward to welcoming you as a sponsor!__

==> mkdocs-material_9.6.4.orig.tar.gz: mkdocs-material-9.6.4/docs/insiders/index.md <==
# Insiders

Material for MkDocs Insiders offers an enhanced experience with early access to
exclusive features that aren't available in the community edition. Become a
sponsor and make use of these features directly!

You’ve already seen the benefits of using Material for MkDocs;
imagine what more you can achieve with Insiders. Your sponsorship helps us
continue to innovate and improve, ensuring Material for MkDocs remains a
cutting-edge tool. Discover how your contributions make a difference.

[&nbsp; Choose a sponsoring tier <span class="mdx-sponsorship-count" data-mdx-component="sponsorship-count"></span>][sponsoring-tiers]{ .md-button .md-button--primary .mdx-sponsorship-button }

  [sponsoring-tiers]: sponsoring-tiers.md

## Additional information

Explore the following section to learn more about Material for MkDocs, why
you should sponsor us, what's in it for you, and who is sponsoring us.

<div class="grid cards" markdown>

-   :fontawesome-solid-circle-question: &nbsp;
    __Why sponsor us__

    ---

    Learn how to support our goal of becoming the leading tool in documentation

    ---

    [:octicons-arrow-right-24: More information][Why sponsor us]

-   :material-gift: &nbsp;
    __What's in it for you__

    ---

    Discover exclusive benefits and features available only to our monthly sponsors

    ---

    [:octicons-arrow-right-24: More information][What's in it for you]

-   :fontawesome-solid-people-group: &nbsp;
    __Who is sponsoring__

    ---

    Get to know our awesome sponsors, financially backing Material for MkDocs

    ---

    [:octicons-arrow-right-24: More information][Who is sponsoring]

</div>

### Sponsoring guide

Learn how to become a sponsor of Material for MkDocs Insiders and start your
sponsorship journey by choosing the right tier for you:

<div class="grid cards" markdown>


-   :material-animation-outline: &nbsp;
    __Sponsoring tiers__

    ---

    Find the perfect monthly sponsoring tier that fits your needs and
    requirements

    ---

    [:octicons-arrow-right-24: More information][Sponsoring tiers]

-   :octicons-heart-fill-24:{ .mdx-heart } &nbsp;
    __How to sponsor__

    ---

    Follow our step-by-step guide on how to become a sponsor to get you started

    ---

    [:octicons-arrow-right-24: More information][How to sponsor]

</div>

### Additional information

If you require additional and detailed information about payment, billing,
access management, and more, here is everything you need to know:

<div class="grid cards" markdown>

-   :material-hand-coin: &nbsp;
    __Payment and billing__

    ---

    All the information you need about payment methods and billing cycles

    ---

    [:octicons-arrow-right-24: More information][Payment and billing]

-   :material-key-variant: &nbsp;
    __Access management__

    ---

    Learn about access management to Insiders – for individuals and
    organizations

    ---

    [:octicons-arrow-right-24: More information][Access management]

-   :material-clock-time-three: &nbsp;
    __Runtime and cancellation__

    ---

    Receive information on the duration of your sponsorship and the cancellation
    process

    ---

    [:octicons-arrow-right-24: More information][Runtime and cancellation]

-   :material-lock-open: &nbsp;
    __Privacy__

    ---

    Our commitment to your privacy – learn assurances on valuing your privacy

    ---

    [:octicons-arrow-right-24: More information][Privacy]

-   :material-briefcase: &nbsp;
    __License__

    ---

    Get details on the licensing of Material for MkDocs Insiders and its requirements

    ---

    [:octicons-arrow-right-24: More information][License]

-   :material-email: &nbsp;
    __Support__

    ---

    Overview of our support options available, ensuring you get the information
    you need

    ---

    [:octicons-arrow-right-24: More information][Support]

</div>

### Using Insiders

Once you have become a sponsor, you can start using Material for MkDocs Insiders,
get all the information you need to get started:

<div class="grid cards" markdown>

-   :material-download: &nbsp;
    __Getting started__

    ---

    Step-by-step instructions on how to install Material for MkDocs Insiders

    ---

    [:octicons-arrow-right-24: More information][Getting started]

-   :octicons-versions-16: &nbsp;
    __Changelog__

    ---

    Review the latest changes and additions to Material for MkDocs Insiders

    ---

    [:octicons-arrow-right-24: More information][Changelog]

-   :material-update:&nbsp;
    __Upgrade__

    ---

    Stay updated with the latest changes and improvements in the Insiders
    edition

    ---

    [:octicons-arrow-right-24: More information][Upgrade]

</div>

  [Why sponsor us]: why-sponsor-us.md
  [What's in it for you]: benefits.md
  [Who is sponsoring]: our-sponsors.md
  [Sponsoring tiers]: sponsoring-tiers.md
  [How to sponsor]: how-to-sponsor.md
  [Payment and billing]: payment-and-billing.md
  [Access management]: access-management.md
  [Runtime and cancellation]: runtime-and-cancellation.md
  [Privacy]: privacy.md
  [License]: license.md
  [Support]: ../support.md
  [Getting started]: getting-started.md
  [Changelog]: ../changelog/index.md
  [Upgrade]: upgrade.md

----

__We're looking forward to welcoming you as a sponsor!__
